===============
Flask-LazyViews
===============

.. image:: https://secure.travis-ci.org/playpauseandstop/Flask-LazyViews.png?branch=master
    :target: https://travis-ci.org/playpauseandstop/Flask-LazyViews

.. image:: https://pypip.in/v/Flask-LazyViews/badge.png
    :target: https://pypi.python.org/pypi/Flask-LazyViews

Registers URL routes for `Flask <http://flask.pocoo.org/>`_ application or
blueprint in lazy way. Ships with additional support of registering admin
views, error handlers, custom static files and rendering Jinja2 templates.

* Based on original `snippet
  <http://flask.pocoo.org/docs/patterns/lazyloading/>`_ from Flask
  documentation
* Works on Python 2.6, 2.7 and 3.3+
* BSD licensed
* Latest documentation `on Read the Docs
  <http://flask-lazyviews.readthedocs.org/>`_
* Source, issues and pull requests `on GitHub
  <https://github.com/playpauseandstop/Flask-LazyViews>`_
* Install with ``pip install Flask-LazyViews``
